==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/en-ID/admin/users/table.php <==
<?php

return array(
    'activated'  			=> 'Aktif',
    'allow'  				=> 'Izinkan',
    'checkedout'  			=> 'Aset',
    'created_at' 			=> 'Dibuat',
    'createuser' 			=> 'Membuat pengguna',
    'deny'  				=> 'Tolak',
    'email'      			=> 'Surel',
    'employee_num'      	=> 'Nomor karyawan.',
    'first_name' 			=> 'Nama depan',
    'groupnotes'			=> 'Pilih grup yang akan ditetapkan ke pengguna, ingat bahwa pengguna mengambil hak akses grup yang ditetapkan.',
    'id'         			=> 'Id',
    'inherit'  				=> 'Mewarisi',
    'job' 					=> 'Judul pekerjaan',
    'last_login'  			=> 'Masuk terakhir',
    'last_name'  			=> 'Nama Belakang',
    'location'  			=> 'Lokasi',
    'lock_passwords'		=> 'Rincian masuk tidak dapat diubah pada instalasi ini.',
    'manager' 				=> 'Manajer',
    'managed_locations'     => 'Lokasi yang Dikelola',
    'name' 					=> 'Nama',
    'notes'                 => 'Catatan',
    'password_confirm' 		=> 'Konfirmasi kata sandi',
    'password' 				=> 'Kata Sandi',
    'phone'  				=> 'Telepon',
    'show_current'          => 'Tampilkan pengguna saat ini',
    'show_deleted'          => 'Tampilkan pengguna yang dihapus',
    'title' 				=> 'Judul',
	'to_restore_them'		=> 'untuk mengembalikan mereka.',
    'updateuser' 			=> 'Perbarui pengguna',
    'username' 				=> 'Nama pengguna',
	'user_deleted_text' 	=> 'Pengguna ini sudah ditandai sebagai sudah terhapus.',
    'username_note' 		=> '(Ini hanya digunakan untuk mengikat Direktori Aktif saja, bukan untuk login.)',
    'cloneuser'             => 'Gandakan pengguna',
    'viewusers' 			=> 'Tampilkan pengguna',
);

==> snipe-it-6.3.0.zip: snipe-it-6.3.0/resources/lang/en-ID/admin/users/table.php <==
<?php

return array(
    'activated'  			=> 'Aktif',
    'allow'  				=> 'Izinkan',
    'checkedout'  			=> 'Aset',
    'created_at' 			=> 'Dibuat',
    'createuser' 			=> 'Membuat pengguna',
    'deny'  				=> 'Tolak',
    'email'      			=> 'Surel',
    'employee_num'      	=> 'Nomor karyawan.',
    'first_name' 			=> 'Nama depan',
    'groupnotes'			=> 'Select a group to assign to the user, remember that a user takes on the permissions of the group they are assigned. Use ctrl+click (or cmd+click on MacOS) to deselect groups.',
    'id'         			=> 'Id',
    'inherit'  				=> 'Mewarisi',
    'job' 					=> 'Judul pekerjaan',
    'last_login'  			=> 'Masuk terakhir',
    'last_name'  			=> 'Nama Belakang',
    'location'  			=> 'Lokasi',
    'lock_passwords'		=> 'Rincian masuk tidak dapat diubah pada instalasi ini.',
    'manager' 				=> 'Manajer',
    'managed_locations'     => 'Lokasi yang Dikelola',
    'name' 					=> 'Nama',
    'nogroup'               => 'No groups have been created yet. To add one, visit: ',
    'notes'                 => 'Catatan',
    'password_confirm' 		=> 'Konfirmasi kata sandi',
    'password' 				=> 'Kata Sandi',
    'phone'  				=> 'Telepon',
    'show_current'          => 'Tampilkan pengguna saat ini',
    'show_deleted'          => 'Tampilkan pengguna yang dihapus',
    'title' 				=> 'Judul',
	'to_restore_them'		=> 'untuk mengembalikan mereka.',
    'total_assets_cost'     => "Total Assets Cost",
    'updateuser' 			=> 'Perbarui pengguna',
    'username' 				=> 'Nama pengguna',
	'user_deleted_text' 	=> 'Pengguna ini sudah ditandai sebagai sudah terhapus.',
    'username_note' 		=> '(Ini hanya digunakan untuk mengikat Direktori Aktif saja, bukan untuk login.)',
    'cloneuser'             => 'Gandakan pengguna',
    'viewusers' 			=> 'Tampilkan pengguna',
);
